import unittest2 as unittest
import os
from alice_pi import configurers
from alice_pi import senders
from alice_pi import measurers
from alice_pi.tests import TEST_DIR


class TestConfigurer(unittest.TestCase):
    config_path = os.path.join(TEST_DIR, 'test_config.yml')

    def test_configure(self):
        conf = configurers.Configurer()
        measurers_and_senders = conf.configure(self.config_path)

        extracted_senders = [item['senders'] for item in measurers_and_senders]
        is_sender = [isinstance(item, senders.Sender)
                     for sublist in extracted_senders for item in sublist]

        self.assertTrue(all(is_sender))

        is_measurer = [isinstance(item['measurer'], measurers.Measurer)
                       for item in measurers_and_senders]

        self.assertTrue(all(is_measurer))



import unittest2 as unittest
import mock
from alice_pi import managers


class TestManager(unittest.TestCase):
    def test_run(self):
        count = 3

        measurer = mock.MagicMock(measure=mock.Mock(side_effect=lambda:  1))
        sender = mock.MagicMock(send=mock.Mock(side_effect=lambda x: 200))

        test = {'measurer': measurer,
                'senders': [sender]}

        man = managers.Manager([test])

        man.run(count=count)

        # assert we check the measurer every time
        self.assertEquals(measurer.measure.call_count, count)

        # since we are recording the same measurement, we will only send once
        self.assertEquals(sender.send.call_count, 1)


if __name__ == '__main__':
    unittest.main()



#!/env/bin/python

from w1thermsensor import W1ThermSensor
import os
import time
import argparse
from alice_pi import configurers
from alice_pi import managers

abspath = os.path.abspath(__file__)
dname = os.path.dirname(abspath)

CONFIG_PATHS = [os.curdir, os.path.expanduser('~'),
                os.environ.get('ALICE_PI_CONFIG_DIR', '')]

def load_config():
    conf = configurers.Configurer()

    for dir in CONFIG_PATHS:
        try:
            measurers = conf.configure(os.path.join(dir,
                                                    'alice_pi_config.yml'))
            return measurers
        except IOError:
            pass

def main():
    measurers_and_senders = load_config()

    man = managers.Manager(measurers_and_senders)

    man.run()

if __name__ == "__main__":
    main()



"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
import os


setup(
    name='alice_pi',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.0.10',

    description=('A package for running various home-automation' +
                 'services on raspberry pi.'),
    long_description=('This package is designed to run many sensor monitoring' +
                      ' and data pushing events asynchronously.  It is' +
                      ' inspired by and made to integrate with Home Assistant'),

    # The project's main homepage.
    url='https://github.com/jlmcgehee21/alice_pi',

    # Author details
    author='Jeff Mcgehee',
    author_email='jlmcgehee21@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='automation sensors raspberrypi',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),


    install_requires=['pyyaml',
                      'requests',
                      'rpi.gpio',
                      'w1thermsensor'],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
        'dev': [],
        'test': ['nose'],
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
        # 'sample': ['package_data.dat'],
    # },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    data_files=[(os.path.expanduser('~'),
                ['alice_pi/data/alice_pi_config.yml.example'])],

    include_package_data=True,

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'alice_pi = alice_pi.bin.run_alice:main',
        ],
    },
)



import unittest2 as unittest
import mock
from alice_pi import measurers
import random


class TestTemperatureMeasurer(unittest.TestCase):

    @mock.patch('alice_pi.measurers.W1ThermSensor')
    def test_measure(self, mock_get_temp):
        test_temp = 10 + random.random()

        mock_get_temp = mock_get_temp.return_value
        mock_get_temp.get_temperature = mock.MagicMock()
        mock_get_temp.get_temperature.return_value = test_temp

        meas = measurers.TemperatureMeasurer('F', n_decimals=2)

        temp = meas.measure()

        self.assertEquals(temp, round(test_temp, 2))


if __name__ == '__main__':
    unittest.main()
